@@ -169,7 +169,7 @@ fn random_search_big() {
         None,
         None,
         None,
-        BIG_LIMIT, // billion
+        BIG_LIMIT,
     );
 }
 
@@ -181,6 +181,7 @@ fn grid_search_simple_function() {
         simple_function,
         None,
         Some(Polling::new(false, Some(SIMPLE_EXIT))),
+        None,
         [GRID_SIMPLE_LIMIT, GRID_SIMPLE_LIMIT, GRID_SIMPLE_LIMIT],
     );
 }
@@ -196,6 +197,7 @@ fn grid_search_complex_function() {
         complex_function,
         None,
         Some(Polling::new(false, Some(COMPLEX_EXIT))),
+        None,
         [
             GRID_COMPLEX_LIMIT,
             GRID_COMPLEX_LIMIT,
@@ -212,6 +214,7 @@ fn grid_search_boundary() {
         boundary_function,
         images.clone(),
         Some(Polling::new(false, Some(0.))),
+        None,
         [255],
     );
 }
@@ -221,6 +224,7 @@ fn grid_search_big() {
         simple_function,
         None,
         None,
+        None,
         [GRID_BIG_LIMIT, GRID_BIG_LIMIT, GRID_BIG_LIMIT],
     );
 }
@@ -291,9 +295,7 @@ fn simulated_annealing_big() {
     );
 }
 
-pub fn criterion_benchmark(c: &mut Criterion) {
-    // Random search
-    // -----------------------------------
+pub fn random_search(c: &mut Criterion) {
     c.bench_function("random_search_simple_function", |b| {
         b.iter(|| random_search_simple_function())
     });
@@ -304,9 +306,8 @@ pub fn criterion_benchmark(c: &mut Criterion) {
         b.iter(|| random_search_boundary())
     });
     c.bench_function("random_search_big", |b| b.iter(|| random_search_big()));
-
-    // Grid search
-    // -----------------------------------
+}
+pub fn grid_search(c: &mut Criterion) {
     c.bench_function("grid_search_simple_function", |b| {
         b.iter(|| grid_search_simple_function())
     });
@@ -317,9 +318,9 @@ pub fn criterion_benchmark(c: &mut Criterion) {
         b.iter(|| grid_search_boundary())
     });
     c.bench_function("grid_search_big", |b| b.iter(|| grid_search_big()));
+}
 
-    // Simulated annealing
-    // -----------------------------------
+pub fn simulated_annealing(c: &mut Criterion) {
     c.bench_function("simulated_annealing_simple_function", |b| {
         b.iter(|| simulated_annealing_simple_function())
     });
@@ -333,5 +334,5 @@ pub fn criterion_benchmark(c: &mut Criterion) {
         b.iter(|| simulated_annealing_big())
     });
 }
-criterion_group!(benches, criterion_benchmark);
+criterion_group!(benches, random_search, grid_search, simulated_annealing);
 criterion_main!(benches);
